@@ -107,9 +107,9 @@ Uploaders: Dr. Tobias Quathamer <toddy@debian.org>
 Section: doc
 Priority: optional
 Build-Depends: debhelper-compat (= 12)
-Build-Depends-Indep: po4a
+Build-Depends-Indep: po4a (>> 0.71)
 Rules-Requires-Root: no
-Standards-Version: 4.6.2
+Standards-Version: 4.7.0
 Vcs-Browser: https://salsa.debian.org/debian/manpages-l10n
 Vcs-Git: https://salsa.debian.org/debian/manpages-l10n.git
 Homepage: https://manpages-l10n-team.pages.debian.net/manpages-l10n/
